@@ -25,6 +25,9 @@ from calculate.lib.cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
+def round_disk_size(size):
+    return size - (size % (4 * Sizes.M))
+
 class VolumesError(Exception):
     pass
 
@@ -184,8 +187,8 @@ class SizeableDisk(object):
     header_size = 0
 
     def __init__(self, size):
-        self.disk_size = size
-        self.free_size = size - self.header_size
+        self.disk_size = round_disk_size(size)
+        self.free_size = self.disk_size - self.header_size
 
     def occupe_size(self, size):
         if size is not self.AllFree:
@@ -227,7 +230,7 @@ class VirtualDisk(SizeableDisk, DosDisk, GptDisk):
             self.mount = mount
             self.part = part
             self.partid = partid
-            self.size = size
+            self.size = round_disk_size(size)
             self.format = ""
 
     def __init__(self, parent, dev, size):
@@ -433,7 +436,7 @@ class Fdisk(SizeableDisk):
                 bytesize = self.free_size + size
             else:
                 bytesize = size
-            return "+%d" % (Sizes().to_Sector(bytesize)-1)
+            return "+%dK" % (Sizes().to_K(bytesize))
         else:
             return ""
 
@@ -570,7 +573,7 @@ class LvmVolumeGroup(SizeableDisk, LvmDisk):
                 bytesize = self.free_size + size
             else:
                 bytesize = size
-            return "-L%ss" % (Sizes().to_Sector(bytesize)-1)
+            return "-L%sk" % (Sizes().to_K(bytesize))
         else:
             return "-l100%FREE"
 
@@ -627,13 +630,15 @@ class RoundableVolumesBuilder(VolumesBuilder):
 
     def is_roundable_size(self, size):
         if (size is not VolumesBuilder.SizeAllFree and size and
-                    abs(size - self.free_size) < size * self.rounding):
+                    abs(size - self.free_size) < min(size * self.rounding,
+                                                     100 * Sizes.M)):
             return True
         return False
 
     def refined_size(self, size):
         if size is VolumesBuilder.SizeAllFree and self.minimal:
-            if self.minimal > self.free_size:
+            if (self.minimal > self.free_size and 
+                not self.is_roundable_size(self.minimal)):
                 return self.minimal
         if self.last_partition:
             if self.is_roundable_size(size):
@@ -1037,7 +1042,7 @@ class SchemeBuilder(object):
         self.update = False
         self.calculate = False
         self.rootall = False
-        self.rounding = 0.01
+        self.rounding = 0.1
         self.vgname = "calculate"
 
         self.extsize = None
